(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7061,        255]*)
(*NotebookOutlinePosition[      8133,        293]*)
(*  CellTagsIndexPosition[      8056,        287]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Buck PWM Converter", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell["Load the Package", "Section",
  Evaluatable->False,
  CellHorizontalScrolling->False],

Cell[BoxData[{
    \(<< NodAl.m\), "\n", 
    \(<< Average.m\), "\n", 
    \(<< KBM.m\), "\n", 
    \(<< Graphic.m\)}], "Input",
  CellTags->"Load Package"],

Cell[CellGroupData[{

Cell[TextData["Topology Description"], "Section",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Circuit Description"], "Subsection",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["\<\
NetList = {{VoltageSource, {1, 0}, Vi},
           {Switch, {1, 2}, S},
           {Switch, {2, 0}, D},
           {Inductor, {2, 3}, L},
           {Capacitor, {3, 0}, C},
           {Resistor, {3, 0}, R}};
InputVars = {Vi};\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True,
  Background->RGBColor[0, 1, 1]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["State-Space Model"], "Section",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[TextData["Switching Sequence"], "Subsection",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["SwitchStates = {{S -> 1, D -> 0}, {S -> 0, D -> 1}};", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True,
  Background->RGBColor[0, 1, 1]]
}, Open  ]],

Cell["State-Space Models", "Subsection",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({A, \ B, \ StateVars}\  = \ 
      StateSpaceModel[NetList, \ InputVars, \ SwitchStates]\)], "Input",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \({\(ib[4]\)[t] \[Rule] \(x[1]\)[t], \(vn[3]\)[t] \[Rule] \(x[2]\)[
          t]}\)], "Output"],

Cell[BoxData[
    \({{{{0, \(-\(1\/L\)\)}, {1\/C, \(-\(1\/\(C\ R\)\)\)}}, {{0, \
\(-\(1\/L\)\)}, {1\/C, \(-\(1\/\(C\ R\)\)\)}}}, {{{1\/L}, {0}}, {{0}, {0}}}, \
{\(x[1]\)[t], \(x[2]\)[t]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Averaged Model"], "Section",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Additional Inputs", "Subsection",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell["SlowFast = {{1, 2}, {}};", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.500008, 1, 1]],

Cell[BoxData[{
    \(\(ns\  = \ Length[SlowFast[\([1]\)]];\)\), "\n", 
    \(\(nf\  = \ Length[SlowFast[\([2]\)]];\)\), "\n", 
    \(\(SlowVars\  = \ 
        Table[StateVars[\([SlowFast[\([1, \ i]\)]]\)]\  /. \ {t\  -> \ 
                t0}, \ {i, \ 1, \ ns}];\)\), "\n", 
    \(\(FastVars\  = \ 
        If[nf == 0, \ {}, 
          Table[StateVars[\([SlowFast[\([2, \ i]\)]]\)], \ \ {i, \ 1, \ 
              nf}]];\)\)}], "Input"],

Cell["\<\
BCs = {0, (d Ts), Ts};
IV = {};\
\>", "Input",
  PageWidth->Infinity,
  AspectRatioFixed->True,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.500008, 1, 1]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Averaged Modeling", "Subsection",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(FastSolus\  = \ 
        Relaxation[A, \ B, \ InputVars, \ SlowFast, \ SlowVars, \ FastVars, \ 
          BCs, \ IV];\)\)], "Input"],

Cell[BoxData[
    \(First::"first" \(\(:\)\(\ \)\) 
      "\!\({}\) has a length of zero and no first element."\)], "Message"],

Cell[BoxData[
    \(First::"first" \(\(:\)\(\ \)\) 
      "\!\({}\) has a length of zero and no first element."\)], "Message"],

Cell[BoxData[
    \(First::"first" \(\(:\)\(\ \)\) 
      "\!\({}\) has a length of zero and no first element."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(First :: \"first\"\) will be suppressed during \
this calculation."\)], "Message"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    \(\(SlowEqus\  = \ 
        Decoupling[FastSolus, \ A, \ B, \ SlowFast, \ SlowVars, \ 
          InputVars, \ FastSolus[\([3]\)]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(AveragedModel\  = \ 
        Averaging[SlowEqus, BCs[\([\(-1\)]\)]];\)\), "\n", 
    \(Simplify[
      AveragedModel\  /. {\(x[1]\)[t0]\  -> \ iL, \ \(x[2]\)[t0]\  -> \ 
            vC}]\)}], "Input"],

Cell[BoxData[
    \({\(\(-vC\) + d\ Vi\)\/L, \(iL\ R - vC\)\/\(C\ R\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ripple Estimation", "Section",
  Evaluatable->False,
  CellHorizontalScrolling->False],

Cell["Ripple = KBM[SlowEqus, AveragedModel, SlowVars, 2];", "Input",
  PageWidth->Infinity]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      Ripple[\([2]\)]\  /. \ {\(x[1]\)[t0]\  -> \ iL, \ \(x[2]\)[t0]\  -> \ 
            vC}]\)], "Input"],

Cell[BoxData[
    \({{{\(\((\(-1\) + d)\)\ \((\(-2\)\ t + d\ Ts)\)\ Vi\)\/\(2\ L\), 
          0}, {\(d\ \((\(-2\)\ t + Ts + d\ Ts)\)\ Vi\)\/\(2\ L\), 0}}, {{0, 
          0}, {0, 0}}}\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Manual,
WindowSize->{920, 791},
WindowMargins->{{Automatic, 92}, {Automatic, 4}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.25,
StyleDefinitions -> "Report.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Load Package"->{
    Cell[1898, 57, 156, 5, 104, "Input",
      CellTags->"Load Package"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Load Package", 7956, 280}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 84, 2, 99, "Title"],
Cell[1804, 53, 91, 2, 84, "Section",
  Evaluatable->False],
Cell[1898, 57, 156, 5, 104, "Input",
  CellTags->"Load Package"],

Cell[CellGroupData[{
Cell[2079, 66, 131, 3, 84, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2235, 73, 133, 3, 49, "Subsection",
  Evaluatable->False],
Cell[2371, 78, 332, 11, 154, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2752, 95, 128, 3, 84, "Section",
  Evaluatable->False],
Cell[2883, 100, 132, 3, 49, "Subsection",
  Evaluatable->False],
Cell[3018, 105, 151, 3, 40, "Input"]
}, Open  ]],
Cell[3184, 111, 122, 3, 49, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3331, 118, 154, 3, 41, "Input"],
Cell[3488, 123, 113, 2, 60, "Output"],
Cell[3604, 127, 201, 3, 112, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3842, 135, 125, 3, 84, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3992, 142, 121, 3, 49, "Subsection",
  Evaluatable->False],
Cell[4116, 147, 224, 7, 40, "Input"],
Cell[4343, 156, 435, 9, 104, "Input"],
Cell[4781, 167, 239, 10, 59, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5069, 183, 121, 3, 49, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5215, 190, 154, 3, 41, "Input"],
Cell[5372, 195, 126, 2, 40, "Message"],
Cell[5501, 199, 126, 2, 40, "Message"],
Cell[5630, 203, 126, 2, 40, "Message"],
Cell[5759, 207, 164, 3, 40, "Message"]
}, Open  ]]
}, Open  ]],
Cell[5950, 214, 163, 3, 41, "Input"],

Cell[CellGroupData[{
Cell[6138, 221, 223, 5, 62, "Input"],
Cell[6364, 228, 84, 1, 75, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6485, 234, 92, 2, 84, "Section",
  Evaluatable->False],
Cell[6580, 238, 91, 1, 40, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6708, 244, 136, 3, 41, "Input"],
Cell[6847, 249, 198, 3, 75, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

